==> calamares-settings-solydxk_4.12%2Br13.tar.xz: source/ts/calamares-solydxk_nb.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Takk for at du valgte SolydXK&lt;/h3&gt;&lt;br /&gt;Du har valgt en Linux-distribusjon som er:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sikker og stabil&lt;/li&gt;&lt;li&gt;Rask og responsive&lt;/li&gt;&lt;li&gt;Klar for skrivebord&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Kos deg med denne utgaven og takk for at du valgte SolydXK.&lt;br /&gt;&lt;br /&gt;Installasjonen tar 15-30 minutter, avhengig av innstillingene dine.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Står på skuldrene til giganter&lt;/h3&gt;&lt;br /&gt;SolydXK er en Debian-basert GNU/Linux distribusjon avledet av og kompatibel  med Debian.&lt;br /&gt;&lt;br /&gt;SolydXK bruker enten det lette Xfce-skrivebordet for SolydX eller det svært  konfigurerbare og utrolig attraktivte KDE-skrivebordet for SolydK.&lt;br /&gt;&lt;br /&gt;Våre innovasjoner, den raske utviklingen av Debian og det enorme utvalget av  Debian-pakker gjør SolydXK til ett av de mest attraktive skrivebords- operativsystemer tilgjengelig for hjemmebrukere.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Ferdig installert&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird og LibreOffice  kommer forhåndsinstallert i SolydXK,  slik at du umiddelbart kan begynne å bruke datamaskinen og Internett.&lt;br /&gt;&lt;br /&gt;I motsetning til andre Linux-distribusjoner er SolydXK også klar til å  spille musikk, internett-videoer og mer.&lt;br /&gt;&lt;br /&gt;Du kan installere et vidt spekter av programvare med et museklikk.&lt;br /&gt;&lt;br /&gt;SolydXK er kompatibel med de fleste populære filformatene slik som: docx,  xlsx, doc, xls, pdf, zip, rar, mp3, mpg og mange andre.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Kontorverktøy er klar til bruk så snart du har installert SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, en kraftig kontorpakke, kommer innebygget i SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice er veldig lett å lære og å bruke.&lt;br /&gt;&lt;br /&gt;Du kan bruke den til å skrive brev, lage presentasjoner og regneark, samt  diagrammer og databaser.&lt;br /&gt;&lt;br /&gt;LibreOffice bruker standard OpenDocument-format og fungerer med  dokumenter fra andre populære kontorprogrammer inkludert WordPerfect and  Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.&lt;br /&gt;&lt;br /&gt;SolydXK can detect other operating systems and install itself beside them.You can choose which operating system to launch when you start the computer.</source>
        <translation>&lt;h3&gt;Et alternativ til større og mer kjente operativsystem&lt;/h3&gt;&lt;br /&gt;SolydXK er lett å bruke, kraftig og enkel å tilpasse.&lt;br /&gt;&lt;br /&gt;SolydXK er sikker og stabil. I motsetning til andre operativsystemer, er det  ikke utsatt for datavirus eller spionprogrammer. Det er ikke plaget av disk- fragmentering og det har ikke noe register som krever periodisk vedlikehold.&lt;br /&gt;&lt;br /&gt;SolydXK kan oppdage andre operativsystemer og installere seg selv ved siden  av dem. Du kan velge hvilket operativsystem du vil bruke når du starter  datamaskinen.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="143"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Sikre oppdateringer&lt;/h3&gt;&lt;br /&gt;Noen operativsystemer gjør oppdateringer av systemet vanskeligere enn det  trenger å være. SolydXK mener at oppgraderinger bør være raske og enkle og  holde seg ute av veien.&lt;br /&gt;&lt;br /&gt;Oppdateringsbehandleren sitter diskret i systemstatusfeltet, og gir deg  beskjed når oppdateringer er tilgjengelige. Du trenger ikke å installere  oppdateringer når det ikke passer. Oppdateringsbehandleren vil ikke poppe  opp eller irritere deg på noen måte.&lt;br /&gt;&lt;br /&gt;Alle oppdaterte filer er vedlikeholdt og nøye sjekket av tiltrodde utviklere  og vedlikeholdere.&lt;br /&gt;&lt;br /&gt;Alle filene er lagret i spesielle sikre pakkebrønner tilgjengelig for deg.&lt;br /&gt;&lt;br /&gt;Sikkerhetsbrønnen synkroniseres hver dag.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="165"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Et flott fellesskap&lt;/h3&gt;&lt;br /&gt;SolydXK brukere er som regel glade for å dele sin lidenskap og begeistring,  og er ivrige etter å hjelpe. Ikke nøl med å stille spørsmål i forumet, eller  å engasjere deg i samfunnet.&lt;br /&gt;&lt;br /&gt;Send oss en tilbakemelding og fortell om dine erfaringer. Vi vil lytte til  dine ideer og bruke dem til å ytterligere forbedre SolydXK.</translation>
    </message>
</context>
</TS>

==> calamares-settings-solydxk_4.27%2Br13.tar.xz: source/ts/calamares-solydxk_nb.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nb" sourcelanguage="en_US">
<context>
    <name>show</name>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="40"/>
        <source>&lt;h3&gt;Thank you for choosing SolydXK&lt;/h3&gt;&lt;br /&gt;You&apos;ve chosen a Linux distribution that is:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Secure and stable&lt;/li&gt;&lt;li&gt;Fast and responsive&lt;/li&gt;&lt;li&gt;Desktop-ready&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Enjoy this new release and thank you for choosing SolydXK.&lt;br /&gt;&lt;br /&gt;The installation takes 15-30 minutes, depending on your settings.</source>
        <translation>&lt;h3&gt;Takk for at du valgte SolydXK&lt;/h3&gt;&lt;br /&gt;Du har valgt en Linux-distribusjon som er:&lt;br /&gt;&lt;ul&gt;&lt;li&gt;Sikker og stabil&lt;/li&gt;&lt;li&gt;Rask og responsive&lt;/li&gt;&lt;li&gt;Klar for skrivebord&lt;/li&gt;&lt;/ul&gt;&lt;br /&gt;Kos deg med denne utgaven og takk for at du valgte SolydXK.&lt;br /&gt;&lt;br /&gt;Installasjonen tar 15-30 minutter, avhengig av innstillingene dine.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="61"/>
        <source>&lt;h3&gt;Standing on the shoulders of Giants&lt;/h3&gt;&lt;br /&gt;SolydXK is a Debian-based GNU/Linux distribution derived from and compatible with Debian.&lt;br /&gt;&lt;br /&gt;SolydXK uses either the lightweight Xfce desktop for SolydX or the highly configurable and stunningly appealing KDE desktop for SolydK.&lt;br /&gt;&lt;br /&gt;Our innovations, the rapid development of Debian and the huge Debian package selection make SolydXK one of the most attractive desktop operating systems available to home users.</source>
        <translation>&lt;h3&gt;Står på skuldrene til giganter&lt;/h3&gt;&lt;br /&gt;SolydXK er en Debian-basert GNU/Linux distribusjon avledet av og kompatibel  med Debian.&lt;br /&gt;&lt;br /&gt;SolydXK bruker enten det lette Xfce-skrivebordet for SolydX eller det svært  konfigurerbare og utrolig attraktivte KDE-skrivebordet for SolydK.&lt;br /&gt;&lt;br /&gt;Våre innovasjoner, den raske utviklingen av Debian og det enorme utvalget av  Debian-pakker gjør SolydXK til ett av de mest attraktive skrivebords- operativsystemer tilgjengelig for hjemmebrukere.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="81"/>
        <source>&lt;h3&gt;Out of the box&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird, and LibreOffice come pre-installed in SolydXK, so you can get started immediately with the desktop and the Internet.&lt;br /&gt;&lt;br /&gt;Unlike other Linux distributions SolydXK is also ready to play your music, internet videos and more.&lt;br /&gt;&lt;br /&gt;A wide variety of software can be installed with a click of the mouse.&lt;br /&gt;&lt;br /&gt;SolydXK is compatible with most popular file formats such as: docx, xlsx, doc, xls, pdf, zip, rar, mp3, mpg, and many more.</source>
        <translation>&lt;h3&gt;Ferdig installert&lt;/h3&gt;&lt;br /&gt;Firefox, Thunderbird og LibreOffice  kommer forhåndsinstallert i SolydXK,  slik at du umiddelbart kan begynne å bruke datamaskinen og Internett.&lt;br /&gt;&lt;br /&gt;I motsetning til andre Linux-distribusjoner er SolydXK også klar til å  spille musikk, internett-videoer og mer.&lt;br /&gt;&lt;br /&gt;Du kan installere et vidt spekter av programvare med et museklikk.&lt;br /&gt;&lt;br /&gt;SolydXK er kompatibel med de fleste populære filformatene slik som: docx,  xlsx, doc, xls, pdf, zip, rar, mp3, mpg og mange andre.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="102"/>
        <source>&lt;h3&gt;Office tools are ready to use as soon as you install SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, a powerful office software suite, comes built into SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice is very easy to learn and use.&lt;br /&gt;&lt;br /&gt;You can use it to create letters, presentations and spreadsheets, as well as diagrams and databases.&lt;br /&gt;&lt;br /&gt;LibreOffice uses the standard OpenDocument format and it works with documents from other popular office applications including WordPerfect and Microsoft Office.</source>
        <translation>&lt;h3&gt;Kontorverktøy er klar til bruk så snart du har installert SolydXK&lt;/h3&gt;&lt;br /&gt;LibreOffice, en kraftig kontorpakke, kommer innebygget i SolydXK.&lt;br /&gt;&lt;br /&gt;LibreOffice er veldig lett å lære og å bruke.&lt;br /&gt;&lt;br /&gt;Du kan bruke den til å skrive brev, lage presentasjoner og regneark, samt  diagrammer og databaser.&lt;br /&gt;&lt;br /&gt;LibreOffice bruker standard OpenDocument-format og fungerer med  dokumenter fra andre populære kontorprogrammer inkludert WordPerfect and  Microsoft Office.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="123"/>
        <source>&lt;h3&gt;An alternative to mainstream operating systems&lt;/h3&gt;&lt;br /&gt;SolydXK is easy to use, powerful and configurable.&lt;br /&gt;&lt;br /&gt;SolydXK is safe and stable. Unlike other operating systems, it is not prone to computer viruses or spyware, it does not suffer from disk fragmentation, and it has no registry that requires periodic cleaning.</source>
        <translation>&lt;h3&gt;Et alternativ til større og mer kjente operativsystem&lt;/h3&gt;&lt;br /&gt;SolydXK er lett å bruke, kraftig og enkel å tilpasse.&lt;br /&gt;&lt;br /&gt;SolydXK er sikker og stabil. I motsetning til andre operativsystemer, er det  ikke utsatt for datavirus eller spionprogrammer. Det er ikke plaget av disk- fragmentering og det har ikke noe register som krever periodisk vedlikehold.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="142"/>
        <source>&lt;h3&gt;Safe updates&lt;/h3&gt;&lt;br /&gt;Some operating systems make updating your system harder than it really needs to be. SolydXK thinks upgrades should be quick and easy, and then get out of the way.&lt;br /&gt;&lt;br /&gt;The Update Manager sits discreetly in your system tray and lets you know when updates are available. You don&apos;t have to apply updates when you don&apos;t want to. The Update Manager won&apos;t pop up or annoy you in any way.&lt;br /&gt;&lt;br /&gt;All updated files are maintained and closely checked by trusted developers and maintainers.&lt;br /&gt;&lt;br /&gt;All files are stored in special secure repositories for your use.&lt;br /&gt;&lt;br /&gt;The security repository is synchronized daily.</source>
        <translation>&lt;h3&gt;Sikre oppdateringer&lt;/h3&gt;&lt;br /&gt;Noen operativsystemer gjør oppdateringer av systemet vanskeligere enn det  trenger å være. SolydXK mener at oppgraderinger bør være raske og enkle og  holde seg ute av veien.&lt;br /&gt;&lt;br /&gt;Oppdateringsbehandleren sitter diskret i systemstatusfeltet, og gir deg  beskjed når oppdateringer er tilgjengelige. Du trenger ikke å installere  oppdateringer når det ikke passer. Oppdateringsbehandleren vil ikke poppe  opp eller irritere deg på noen måte.&lt;br /&gt;&lt;br /&gt;Alle oppdaterte filer er vedlikeholdt og nøye sjekket av tiltrodde utviklere  og vedlikeholdere.&lt;br /&gt;&lt;br /&gt;Alle filene er lagret i spesielle sikre pakkebrønner tilgjengelig for deg.&lt;br /&gt;&lt;br /&gt;Sikkerhetsbrønnen synkroniseres hver dag.</translation>
    </message>
    <message>
        <location filename="../calamares/branding/solydxk/show.qml" line="164"/>
        <source>&lt;h3&gt;A great community&lt;/h3&gt;&lt;br /&gt;SolydXK users are happy to share their passion and enthusiasm and are eager to help. Don&apos;t hesitate to ask questions on the forums or to get involved in the community.&lt;br /&gt;&lt;br /&gt;Send us your feedback and tell us about your experience. We&apos;ll listen to your ideas and use them to further improve SolydXK.</source>
        <translation>&lt;h3&gt;Et flott fellesskap&lt;/h3&gt;&lt;br /&gt;SolydXK brukere er som regel glade for å dele sin lidenskap og begeistring,  og er ivrige etter å hjelpe. Ikke nøl med å stille spørsmål i forumet, eller  å engasjere deg i samfunnet.&lt;br /&gt;&lt;br /&gt;Send oss en tilbakemelding og fortell om dine erfaringer. Vi vil lytte til  dine ideer og bruke dem til å ytterligere forbedre SolydXK.</translation>
    </message>
</context>
</TS>
